#ifndef GRASP_INC
#define GRASP_INC 1
#include <X11/X.h> /* this is only necessary for ansi ??? tpl*/
/*
 *     Grasp.H
 *
 * Constants and procedure prototypes for EGA/Microsoft C/MetaWindows version
 *
 *     Revised - DNH - 7 April 88
 *         Function declarations now include parameter names
 *
 */

/*
 *       The following defines are MetaWindows specific
 *       ==============================================
 */

/* Supported devices */

#define EGA    1
#define VGA    2
#define VGA480 3

/*   EGA and VGA work on both types of adapter; the only difference is
 *   a slight variation in aspect ratio
 */

/* Fonts */

/* Fontxx are bitmap fonts with xx pixels vertically, 8 pixels horizontally
 * other fonts are stroke type
 * X11: note that these numbers can be used as indices into the modified
   font struct. 
*/
#ifdef MW 
#define Standard   0
#else 
#define Standard   4
#endif  /* MW */
#define Font8      1
#define Simplex    2
#define Triplex    3
#define Font14     4
#define Font19     5
#define Font16     6

#define EGA25      Font14
#define EGA43      Font8
#define VGA60      Font8
#define VGA30      Font16
#define VGA25      Font19

#define Roman1     Simplex
#define Roman2     Triplex


#ifdef MW
#define Maths      -1   /* not available */
#define Greek      -1
#else
#define Maths      7   /* math.8x16 */
#define Vertical   8   /* rot-s16   */
#define Font24     9   /*kana.12x24 */
#define Micro      10  /* micro     */
#define X11Simplex 11  /* gipsubb   */
#define X11Duplex  12  /* gipsubb   */
#define X11Complex 13  /* gipsubb   */
#define X11Italic  14  /* gipsubb   */

/* Control the transparency of font backgrounds */
#define Transparent 1
#define Opaque      2
#endif

/* Colours (EGA default palette )*/

#define Black     0 
#define Blue      1
#define Green     2
#define Cyan      3
#define Red       4
#define Magenta   5
#define Brown     6
#define Grey      7
#define DGrey     8
#define LBlue     9
#define LGreen   10
#define LCyan    11
#define LRed     12
#define LMagenta 13
#define Yellow   14
#define White    15

/* Line Types */

#define Solid    0
#define Dashed   1
#define Dotted   4

/* Drawing modes */

#define Normal    0
#define Or        1
#define Xor       2
#define Invert    2
#define Nand      3
#define Erase     3
#define Not       4
#define Reverse   4
#define Nor       5
#define Inverse   5

/* Fill types */

#define Empty   0
#define Full    1
#define Hatch1  19
#define Hatch2  13
#define Hatch3  21
#define Hatch4  8
#define Hatch5  23
#define Hatch6  24

/*
 *       End of MetaWindows specific defines
 *       ===================================
 */

#define ON    1
#define OFF   0

#define TRUE  1
#define FALSE 0

/* Defaults: Solid line, normal mode drawing, 25 line font, plus marker */

#define Default 0

/* Markers */
#define Plus      0
#define Cross     1
#define Square    2
#define Diamond   3
#define Arrow     4
#define X11Arrow  5
#define X11Cross  6
#define X11Plus   7


/* Cursor types >0 are normal cursor, <0 are rubber band/box */

/* Plus is defined above */
#define Mark      1
#define Ruband    -1
#define Rubox     -2

/* Values returned by grqdev */

#define CurPos 1
#define Aspect 2
#define ChSize 3
#define PlSize 4
#define MkSize 5

/* Error handling: Soft errors */


#ifdef X11
/* XHP routines return values starting from zero (see X11/XHPImageIO.h). 
 * Add an offset to them so they can be passed to grerr without messing
 * up present error values.
 */
#define XHP_ERROR_OFFSET 10
#endif /* X11 */

#define Fatal     -1     /* Treat all errors as fatal */

#define ErrOK      0     /* No problems               */
#define ErrVAL     1     /* Value out of range        */
#define ErrNA      2     /* Not available             */

/* Fatal errors */

#define ErrOPN     -1    /* Plot, save or dump file open error    */
#define ErrWRT     -2    /* Plot or dump file write error         */
#define ErrHW      -3    /* Hardware failure or not installed     */
#define ErrMEM     -4    /* Insufficient free memory              */
#define ErrRD      -5    /* Save file read error                  */

/*
 *                 Procedure prototypes
 *
 */

/* floating point parameters are single precision */

#ifndef real
#ifdef ANSI
#define real float
#else
#define real double
#endif /* ANSI */
#endif

#ifdef ANSI
extern  int  grinit(int device);                                        /* Initialise package                   */
extern  void grdflt(void);                                              /* Set default attributes               */
extern  void grterm(void);                                              /* Terminate graphics                   */
extern  void groff(void);                                               /* Enter text mode                      */
extern  void gron(void);                                                /* Enter graphics mode                  */
extern  void grplon(char *filename,int length);                         /* Open plot file                       */
extern  void grplof(void);                                              /* Close plot file                      */
extern  void grdump(char *filename,int length);                         /* Dump screen to file                  */
extern  int  grctrl(int stream);                                        /* Switch screen/plotter output         */
extern  void grclr(int flag);                                           /* Clear screen or viewport             */
extern  int  grerrt(int flag);                                          /* Default or user error handling       */
extern  int  grqerr(void);                                              /* Current error code                   */
extern  void grqdev(int select,real *val1,real *val2);                  /* Pen posn., device characteristics*/
extern  void grview(real xmn,real xmx,real ymn,real ymx);               /* Set viewport                */
extern  void grqvie(real *xmn,real *xmx,real *ymn,real *ymx);           /* Query viewport              */
#ifdef MW
extern  char *grsave(char *block, long *size);                          /* Save viewport contents (note long parm) */
extern  void grrest(char *block);                                       /* Restore viewport contents   */
#else
extern  Pixmap grsave(Pixmap pixmap);
extern  void grrest(Pixmap pixmap);                                       /* Restore viewport contents   */
#endif /* MW */
extern  void grwind(real umn,real umx,real vmn,real vmx);               /* Set window                  */
extern  void grqwin(real *umn,real *umx,real *vmn,real *vmx);           /* Query window                */
extern  void grclip(int flag);                                          /* Set clipping on/off (Level II) */
extern  void grutod(real u,real v,real *x,real *y);                     /* User to device coords       */
extern  void grdtou(real x,real y,real *u,real *v);                     /* Device to user coords       */
extern  int  grseen(real x,real y);                                     /* TRUE if point is inside viewport (II) */
extern  int  grcol(int colour);                                         /* Set colour                  */
extern  int  grbcol(int colour);                                        /* Set background colour       */
extern  void grinvt(void);                                              /* Swap foreground and background colours */
extern  int  grmode(int mode);                                          /* Set mode                    */
extern  int  grlt(int type);                                            /* Set line type               */
extern  int  grlw(int width);                                           /* Set line width              */
extern  int  grft(int fill_pattern);                                    /* Set fill type               */
extern  real grms(real size);                                           /* Set marker size             */
extern  void grmwh(real width,real height);                             /* Set marker width and height */
extern  int  grmt(int type);                                            /* Set marker type             */
extern  void grmvch(int x, int y);                                      /* Move pen in character units */
extern  void grmvxy(real x,real y);                                     /* Move pen in device units    */
extern  void grdrxy(real x,real y);                                     /* Draw pen in device units    */
extern  void grmove(real u,real v);                                     /* Move in user coords         */
extern  void grdraw(real u,real v);                                     /* Draw in user coords         */
extern  void grmvby(real u,real v);                                     /* Move pen by increment       */
extern  void grdrby(real u,real v);                                     /* Draw pen by increment       */
extern  void grmark(void);                                              /* Draw centred marker         */
extern  void grarc(real xcentre,real ycentre,real angle);               /* Draw circular arc           */
extern  void grpie(real xcentre,real ycentre,real angle);               /* Draw filled circular wedge  */
extern  void grpoly(int n,real *u,real *v);                             /* Draw polyline               */
extern  void grfill(int n,real *u,real *v);                             /* Fill area                   */
extern  void grchar(char *string,int length);                           /* Draw string, length specified */
#ifdef X11
extern void gloc(int *, float *, float*);
extern  void grvtext(char *string);                                      /* Draw string, null terminator  */
extern  void grwarp (real x, real y);                                    /* warp the X11 pointer          */
extern   int grX11font( char *x11fontname );                             /* <=== grX11font  */
extern   int grX11col( char *x11colname );                             /* <=== grX11col  */
extern   int grqcde(void);                                               /* query device */
extern   int grtfbg(int mode);                                           /* set font bg transparency   */
extern   void grwinname( char * name);                                  /* set window name */
#endif
extern  void grtext(char *string);                                      /* Draw string, null terminator  */
extern  void grputi(int val,int width);                                 /* write integer               */
extern  void grputr(real val,int width);                                /* write real                  */
extern  real grchs(real size);                                          /* Set character size          */
extern  void grchwh(real width,real height);                            /* Set character width and height */
extern  real grcha(real angle);                                         /* Set character angle         */
extern  int  grfont(int NewFont);                                       /* Set font                    */
extern  int  grrqch(void);                                              /* Choice input                */
extern  void grrqlc(int *button,real *x,real *y);                       /* Locator input               */
extern  int  grct(int type);                                            /* Set cursor type             */
extern  int  grrqst(char *string,int *length);                          /* String input                */
extern  int  grrqi(void);                                               /* read integer                */
extern  real grrqr(void);                                               /* read real                   */
extern  int  grtime(int time);                                          /* Set timeout interval        */
extern  void grdeff(int string_no,int mode,char *word,int totlen,real Upos,real Vpos);
									/* Define field for input      */
extern  int  grread(void);                                              /* Read input fields           */
extern  void grgetf(int snum,char *word);                               /* Get contents of field       */
#ifdef MW
extern  void grsscr(char *filename, int length);                        /* Save screen to file         */
extern  void grrscr(char *filename, int length);                        /* Reload screen from file     */
#else
extern  void grsscr(char *filename);                                    /* Save screen to file         */
extern  void grrscr(char *filename);                                    /* Reload screen from file     */
#endif /*MW
extern  int  grvpg(int page);                                           /* Set visible page            */
extern  int  grwpg(int page);                                           /* Set output page             */
extern  void grwait();



#else
extern  int  grinit();                                        /* Initialise package                   */
extern  void grdflt();                                              /* Set default attributes               */
extern  void grterm();                                              /* Terminate graphics                   */
extern  void groff();                                               /* Enter text mode                      */
extern  void gron();                                                /* Enter graphics mode                  */
extern  void grplon();                         /* Open plot file                       */
extern  void grplof();                                              /* Close plot file                      */
extern  void grdump();                         /* Dump screen to file                  */
extern  int  grctrl();                                        /* Switch screen/plotter output         */
extern  void grclr();                                           /* Clear screen or viewport             */
extern  int  grerrt();                                          /* Default or user error handling       */
extern  int  grqerr();                                              /* Current error code                   */
extern  void grqdev();                  /* Pen posn., device characteristics*/
extern  void grview();               /* Set viewport                */
extern  void grqvie();           /* Query viewport              */
#ifdef MW
extern  char *grsave();                          /* Save viewport contents (note long parm) */
#else
extern  Pixmap grsave();
#endif /* MW */
extern  void grrest();                                       /* Restore viewport contents   */
extern  void grwind();               /* Set window                  */
extern  void grqwin();           /* Query window                */
extern  void grclip();                                          /* Set clipping on/off (Level II) */
extern  void grutod();                     /* User to device coords       */
extern  void grdtou();                     /* Device to user coords       */
extern  int  grseen();                                     /* TRUE if point is inside viewport (II) */
extern  int  grcol();                                         /* Set colour                  */
extern  int  grbcol();                                        /* Set background colour       */
extern  void grinvt();                                              /* Swap foreground and background colours */
extern  int  grmode();                                          /* Set mode                    */
extern  int  grlt();                                            /* Set line type               */
extern  int  grlw();                                           /* Set line width              */
extern  int  grft();                                    /* Set fill type               */
extern  real grms();                                           /* Set marker size             */
extern  void grmwh();                             /* Set marker width and height */
extern  int  grmt();                                            /* Set marker type             */
extern  void grmvch();                                      /* Move pen in character units */
extern  void grmvxy();                                     /* Move pen in device units    */
extern  void grdrxy();                                     /* Draw pen in device units    */
extern  void grmove();                                     /* Move in user coords         */
extern  void grdraw();                                     /* Draw in user coords         */
extern  void grmvby();                                     /* Move pen by increment       */
extern  void grdrby();                                     /* Draw pen by increment       */
extern  void grmark();                                              /* Draw centred marker         */
extern  void grarc();               /* Draw circular arc           */
extern  void grpie();               /* Draw filled circular wedge  */
extern  void grpoly();                             /* Draw polyline               */
extern  void grfill();                             /* Fill area                   */
extern  void grchar();                           /* Draw string, length specified */
#ifdef X11
extern  void grvtext();                                      /* Draw string, null terminator  */
extern  void grwarp ();                                    /* warp the X11 pointer          */
extern  int  grX11font();
extern  int  grX11col();                             /* <=== grX11col  */

extern   int grqcde();                                               /* query device */
extern   int grtfbg();                                           /* set font bg transparency   */
extern   void grwinname();                                  /* set window name */

#endif
extern  void grtext();                                      /* Draw string, null terminator  */
extern  void grputi();                                 /* write integer               */
extern  void grputr();                                /* write real                  */
extern  real grchs();                                          /* Set character size          */
extern  void grchwh();                            /* Set character width and height */
extern  real grcha();                                         /* Set character angle         */
extern  int  grfont();                                       /* Set font                    */
extern  int  grrqch();                                              /* Choice input                */
extern  void grrqlc();                       /* Locator input               */
extern  int  grct();                                           /* Set cursor type             */
extern  int  grrqst();                          /* String input                */
extern  int  grrqi();                                               /* read integer                */
extern  real grrqr();                                               /* read real                   */
extern  int  grtime();                                          /* Set timeout interval        */
extern  void grdeff();                                /* Define field for input      */
extern  int  grread();                                              /* Read input fields           */
extern  void grgetf();                               /* Get contents of field       */
extern  void grsscr();                        /* Save screen to file         */
extern  void grrscr();                        /* Reload screen from file     */
extern  int  grvpg();                                           /* Set visible page            */
extern  int  grwpg();                                           /* Set output page             */
extern  void grwait();
#endif /* ANSI */
#endif


extern void cymblt();
