C
C     GRASP.INC  ----  Include file for Grasp attributes
C
C  This file contains memonic identifiers for graphics attributes including
C  line colour, marker type etc, and declares FUNCTIONS which are defined
C  as INTEGER in GRASP.DEF
C
C  It should be included in every Fortran routine which calls a Grasp
C  INTEGER FUNCTION, or sets an attribute.
C
C  Example:
C
C        SUBROUTINE BOX
C  $INCLUDE:'GRASP.INC'
C        .
C        .
C        .
C
      INTEGER*4 ON, OFF, TRUE, FALSE, DEFAULT
      PARAMETER ( ON = 1, OFF = 0 )
      PARAMETER ( TRUE = 1, FALSE = 0, DEFAULT = 0 )
C
C         Devices
C
      INTEGER*4 EGA, VGA, VGA480, X11, X11B
C
C EGA and VGA are 640x350 pixels, but have slighlty different aspect ratios
C VGA480 is 640x480 pixels. X11 is 640x480, X11B is 960x720.
C
      PARAMETER ( EGA    = 1 )
      PARAMETER ( VGA    = 2 )
      PARAMETER ( VGA480 = 3 )
      PARAMETER ( X11    = 4 )
      PARAMETER ( X11B   = 5 )


C
C         Fonts
C
      INTEGER*4 Standard, Font8, Font14, Font16, Font19, Simplex,
     + Roman1, Triplex, Roman2, EGA25, EGA43, VGA25, VGA30,
     + Maths ,Vertical, Font24, Micro,
     + X11Simplex, X11Duplex, X11Complex, X11Italic

C
      PARAMETER ( Standard = 0 )
      PARAMETER ( Font8    = 1 )
      PARAMETER ( EGA43    = 1 )
      PARAMETER ( Simplex  = 2 )
      PARAMETER ( Roman1   = 2 )
      PARAMETER ( Triplex  = 3 )
      PARAMETER ( Roman2   = 3 )
      PARAMETER ( Font14   = 4 )
      PARAMETER ( EGA25    = 4 )
      PARAMETER ( Font19   = 5 )
      PARAMETER ( VGA25    = 5 )
      PARAMETER ( Font16   = 6 )
      PARAMETER ( VGA30    = 6 )
      PARAMETER ( Maths    = 7 ) 
      PARAMETER ( Vertical = 8 )
      PARAMETER ( Font24   = 9 )
      PARAMETER ( Micro    =   10 )
      PARAMETER ( X11Simplex = 11 )
      PARAMETER ( X11Duplex  = 12 )
      PARAMETER ( X11Complex = 13 )
      PARAMETER ( X11Italic  = 14 )

C         Fonts Background Transparency
C
      INTEGER*4 TRANSPARENT, OPAQUE

C
      PARAMETER ( TRANSPARENT = 1 )
      PARAMETER ( OPAQUE      = 2 )

C
C         Colours
C
      INTEGER*4 Black, Blue, Green, Cyan, Red, Magenta, Brown, Grey,
     +    DGrey, LBlue, LGreen, LCyan, LRed, LMagenta, Yellow, White

      PARAMETER ( Black   =  0 )
      PARAMETER ( Blue    =  1 )
      PARAMETER ( Green   =  2 )
      PARAMETER ( Cyan    =  3 )
      PARAMETER ( Red     =  4 )
      PARAMETER ( Magenta =  5 )
      PARAMETER ( Brown   =  6 )
      PARAMETER ( Grey    =  7 )
      PARAMETER ( DGrey   =  8 )
      PARAMETER ( LBlue   =  9 )
      PARAMETER ( LGreen  = 10 )
      PARAMETER ( LCyan   = 11 )
      PARAMETER ( LRed    = 12 )
      PARAMETER ( LMagenta= 13 )
      PARAMETER ( Yellow  = 14 )
      PARAMETER ( White   = 15 )

C
C         Line Types
C
      INTEGER*4 Solid, Dashed, Dotted
C
      PARAMETER ( Solid  = 0 )
      PARAMETER ( Dashed = 1 )
      PARAMETER ( Dotted = 4 )
C
C         Drawing modes
C
      INTEGER*4 Normal, Or, Invert, Xor, Nand, Erase, Not, Reverse
C
      PARAMETER ( Normal = 0 )
      PARAMETER ( Or     = 1 )
      PARAMETER ( Invert = 2 )
      PARAMETER ( Xor    = 2 )
      PARAMETER ( Nand   = 3 )
      PARAMETER ( Erase  = 3 )
      PARAMETER ( Not    = 4 )
      PARAMETER ( Reverse= 4 )
      PARAMETER ( Nor    = 5 )
      PARAMETER ( Inverse= 5 )
C
C         Fill types
C
      INTEGER*4 Empty, Full, Hatch1, Hatch2,
     +          Hatch3, Hatch4, Hatch5, Hatch6
C
      PARAMETER ( Empty  =  0 )
      PARAMETER ( Full   =  1 )
      PARAMETER ( Hatch1 = 19 )
      PARAMETER ( Hatch2 = 13 )
      PARAMETER ( Hatch3 = 21 )
      PARAMETER ( Hatch4 =  8 )
      PARAMETER ( Hatch5 = 23 )
      PARAMETER ( Hatch6 = 24 )
C
C         Markers
C
      INTEGER*4 Plus, Cross, Square, Diamond, Arrow
C
      PARAMETER ( Plus    = 0 )
      PARAMETER ( Cross   = 1 )
      PARAMETER ( Square  = 2 )
      PARAMETER ( Diamond = 3 )
      PARAMETER ( Arrow =   4 )
C
C
C Cursor types >0 are normal cursor, <0 are rubber band/box
C
      INTEGER*4 Mark, Ruband, Rubox
C
      PARAMETER ( Mark   =  1 )
      PARAMETER ( Ruband = -1 )
      PARAMETER ( Rubox  = -2 )
C
C         Values returned by grqdev
C
      INTEGER*4 CurPos, Aspect, ChSize, PlSize, MkSize
C
      PARAMETER ( CurPos = 1 )
      PARAMETER ( Aspect = 2 )
      PARAMETER ( ChSize = 3 )
      PARAMETER ( PlSize = 4 )
      PARAMETER ( MkSize = 5 )
C
C         Error handling
C
C    Soft errors
C
      INTEGER*4 ErrOK, ErrVAL, ErrNA
C
      PARAMETER ( ErrOK  = 0 )
      PARAMETER ( ErrVAL = 1 )
      PARAMETER ( ErrNA  = 2 )
C
C    Fatal errors
C
      INTEGER*4 ErrOPN, ErrWRT, ErrHW, ErrMEM
C
      PARAMETER ( ErrOPN = -1 )
      PARAMETER ( ErrWRT = -2 )
      PARAMETER ( ErrHW  = -3 )
      PARAMETER ( ErrMEM = -4 )
      PARAMETER ( ErrRD  = -5 )
C
      INTEGER*4 grinit, grctrl, grqerr, grseen, grcol, grmode, grlt,
     +          grlw, grft, grmt, grfont, grrqch, grct, grrqst,
     +          grrqi, grtime, grread, grerrt, grvpg, grwpg, grbcol,
     +          grtfbg, grqcde
C (grerrt added 16-8-88) - DNH
C (grvpg, wpg added 21-11-88) - DNH
C (grbcol added 7-3-89) - DNH
C (grtfbg, grqcde added 12/3/90) - TPL

